@@ -18,6 +18,14 @@ from sqlalchemy.orm import load_only
 
 
 class PickleNotFoundException(Exception):
+    """Exception raised when an attempt to load an experiment from its Pickle fails
+    as it was not previously stored.
+
+
+    Args:
+        Exception (_type_): _description_
+    """
+
     def __init__(self):
         self.message = "The pickle blob was not found."
         super().__init__(self.message)
@@ -68,11 +76,8 @@ class Experiment:
             db (Database, optional): Database to link to. Defaults to None.
             id_experiment (str, optional): ID of the experiment to be used. Defaults to None.
             name (str, optional): Name of the experiment. Defaults to None.
-            steps (Union[Callable, List[Callable]], optional): One or more functions to call. Defaults to None.
-            kwargs (dict, optional): Fixed parameters passed to the functions. Defaults to None.
             fields (dict, optional): Fixed experiment fields to be tracked. Defaults to None.
             properties (dict, optional): Experiment properties, used to hold meta-attributes. Defaults to None.
-            param_grid (List, optional): Grid of parameters, used to generate the run parameters.
             runs (List[Run], optional): List of runs belonging to the experiment. Defaults to None.
         """
 
@@ -112,17 +117,31 @@ class Experiment:
 
     @contextmanager
     def run(self):
+        """Enter run context
+
+        Yields:
+            _type_: run
+        """
         try:
             run = Run()
             yield run
         finally:
-            self.runs.add(run)  # [str(run.id_run)] = run
+            self.runs.add(run)
 
     def _repr_html_(self):
+        """Experiment representation as HTML, used in notebooks.
+
+        Returns:
+            _type_: HTML.
+        """
         return f'experiment(name="{self.name}", n_runs={len(self.runs)}, id="{self.id_experiment}")'
 
     def add_runs(self, **param_grid):
-        # Populate param_grid
+        """Add runs to the experiment, defining them from Cartesian product of parameter grid.
+
+        Returns:
+            _type_: The experiment (self).
+        """
         if not param_grid:
             param_grid = [{}]
         elif isinstance(param_grid, dict):
@@ -136,7 +155,11 @@ class Experiment:
         return self
 
     def add_run(self, **params):
-        print(params)
+        """Add single run with a list of parameters.
+
+        Returns:
+            _type_: The experiment (self).
+        """
         self.runs.add(Run(params=params))
         return self
 
@@ -150,13 +173,13 @@ class Experiment:
         return sanitize_table_name(f"{options.get('db.experiment_tableprefix')}{self.name}")
 
     @log.default_exception_handler
-    def query(self, query: str = "SELECT * FROM {table_name}", verbose: bool = False) -> pd.DataFrame:
+    def query(self, query: str = "SELECT * FROM {table_name}") -> pd.DataFrame:
         """Query the experiment's table
 
         Args:
-            query (str, optional): SQL query. {e} is replaced with the table name of the experiment.,
-            {id} with the experiment ID, and {ee} with the experiments table. Defaults to the complete record.
-            verbose (bool, optional): If true, print the resulting query. Defaults to False.
+            query (str, optional): SQL query. {name} is replaced with the table name of the experiment,
+                {id} with the experiment ID, {experiment} with the experiment table and {experiments} wtih
+                the experiments table. Defaults to the complete record.
 
         Returns:
             pd.DataFrame: Result of the query.
@@ -169,12 +192,20 @@ class Experiment:
                 experiment=self.tablename(),
                 experiments=options.get("db.experiments_tablename"),
             ),
-            verbose=verbose,
         )
 
         return df
 
     def load_runs(self, run_columns):
+        """Load runs for experiment from db, considering run_columns.
+
+        Args:
+            run_columns (_type_): dictionary that specifies which columns have
+                been serialized or not.
+
+        Returns:
+            _type_: _description_
+        """
         logger.info("Loading runs")
         # Retrieve all columns
         df = self.query(f"select * from {self.tablename()}")
@@ -192,6 +223,15 @@ class Experiment:
         self.runs = Runs(df.apply(lambda row: series_to_run(row), axis=1).values)
 
     def copy(self, name=None):
+        """Deep copy of an experiment.
+
+        Args:
+            name (_type_, optional): Name of the new experiment. If none, the 3words hash
+                is used as name. Defaults to None.
+
+        Returns:
+            _type_: _description_
+        """
         experiment = copy.deepcopy(self)
         experiment.id_experiment = next_ulid()
 
@@ -204,6 +244,19 @@ class Experiment:
 
     @classmethod
     def load_pickle(cls, db: Database, name: str):
+        """Lod experiment from pickle
+
+        Args:
+            db (Database): Database to load the experiment from
+            name (str): Name of the experiment
+
+        Raises:
+            ExperimentNotFoundException: _description_
+            PickleNotFoundException: _description_
+
+        Returns:
+            _type_: _description_
+        """
         logger.info(f"Loading experiment '{name}' (pickle)")
 
         with db.session() as session:
@@ -238,6 +291,7 @@ class Experiment:
         Args:
             db (Database): Reference to a database.
             name (str): Name of the experiment.
+            pickle (bool): If true, load experiment from its Pickle.
 
         Raises:
             ExperimentNotFoundException: Raised if the experiment is not found.
@@ -294,7 +348,8 @@ class Experiment:
 
         Args:
             steps (Union[Callable, List[Callable]], optional): Function(s) that will override the defined ones.
-            If the value is "all", the re-evaluation of all defined functions is forced. Defaults to None.
+                If the value is "all", the re-evaluation of all defined functions is forced. Defaults to None.
+            kwargs: Fixed arguments to pass to the run.
             backend (_type_, optional): Joblib baackend. Defaults to joblib.parallel.DEFAULT_BACKEND.
             n_jobs (int, optional): Parallelization degree, defined as in Joblib. Defaults to -1.
 
@@ -334,7 +389,7 @@ class Experiment:
         )
 
     def info(self):
-        """Print some stats about the experiment.
+        """Return a series with some stats about the experiment.
 
         Returns:
             Experiment: self
@@ -379,6 +434,7 @@ class Experiment:
 
         Args:
             if_exists (IfExists, optional): Either "replace" or "fail". Defaults to "fail".
+            store_pickle: If None, defaults to the configuration. If true or false, honor preference.
 
         Raises:
             ExperimentReadOnlyException: Experiment loaded in SQL read-only mode.
@@ -436,10 +492,10 @@ class Experiment:
 
         Args:
             if_exists (IfExists, optional): Either "replace" or "fail". In case
-            the experiment exists and the value is "replace", nothing happens.
-            If the experiment exists and the value is "fail", it will raise an
-            exception. It is designed to work correctly together with insertions.
-            Defaults to "fail".
+                the experiment exists and the value is "replace", nothing happens.
+                If the experiment exists and the value is "fail", it will raise an
+                exception. It is designed to work correctly together with insertions.
+                Defaults to "fail".
 
         Raises:
             ExperimentAlreadyExists: Raised if the experiment exists.
